@@ -5,7 +5,7 @@ import requests
 
 class Requestor(abc.ABC):
     @abc.abstractmethod
-    def request(self, method, url, params={}, headers={}, cookies={}, *kwargs):
+    def request(self, method, url, params={}, headers={}, cookies={}, **kwargs):
         pass
 
 
